@@ -6,10 +6,14 @@ use Encode;
 
 use Exporter;
 our @ISA = 'Exporter';
-our @EXPORT = ('hashdomain', 'listdomain', 'out','sortuniq', 'treate_accent','treate_dict', 'treate_language');
+our @EXPORT = ('hashdomain', 'listdomain', 'out', 'sortuniq', 'treate_accent',
+  'treate_dict', 'treate_language', 'dictionnary', 'reverse_dic', 'canonify');
+
+sub canonify { my ($w)=@_; treate_accent(lc($w)) }
 
 sub treate_dict { my ($file) = @_;
-   my %ref = ( ) ; my $ref=\%ref; my $text;
+   my %ref = ( ) ; my $ref=\%ref;
+   my $text;
    open IN, "$file";
    while (<IN>) {
    $text = $_ ;
@@ -20,13 +24,29 @@ sub treate_dict { my ($file) = @_;
    my @L = sortuniq(split("\n",$text));
    for my $l (@L) {
      my @la=split(":", $l) ;
-     $ref{$la[0]}=$la[1] if ($la[1]);
+     $ref{canonify($la[0])}=join(':',@la[1..@la-1]) if ($la[1]);
     }
    }
   close IN;
  %ref;
 }
 
+sub dictionnary { my ($file, @words)=@_;
+  my %dic=treate_dict($file) ;
+  my $dic=\%dic;
+  my @W=();
+  if (@words) {
+   for my $w (@words) {
+    next if !($w);
+    for my $ww (split(',', $w)) {
+     if ( $dic{canonify($ww)} ) { push @W, $dic{canonify($ww)} ; };
+     }
+   }
+   sortuniq ( @W )
+   }
+   @W;
+}
+
 sub treate_accent {my ($txt) = @_;
   $txt=decode('iso-8859-1',$txt);
   $txt =~ tr//eeeeaaaaaauiiiioooc/;
@@ -34,6 +54,7 @@ sub treate_accent {my ($txt) = @_;
   $txt =~ s//C/g;
   $txt =~ s/[]/E/g;
   $txt =~ s/[]/I/g;
+  $txt =~ s/'/ /g;
   $txt= encode("iso-8859-1",$txt);
   $txt
 }
@@ -66,6 +87,7 @@ sub listdomain { my ($file)=@_ ;
 ## reversing the domain tree
 
 sub hashdomain { my ($file)=@_;
+ $/ = undef;
  open IN, "$file";
  my %ref = ( ) ; my $ref=\%ref;
  while (<IN>) { my $text=$_ ; $text=~ s/\\\n\s*//g;
@@ -77,8 +99,9 @@ sub hashdomain { my ($file)=@_;
      my @cut=split(":", $line) ;
      if ($cut[1]) {
        my @son=split(',',$cut[1]);
+       $ref->{'next'}{$cut[0]}=$cut[1];
       for my $s (@son) {
-        if ($ref{$s}) { $ref{$s} .= "," . $cut[0]} else {$ref{$s} = $cut[0]}
+        if ($ref->{'prev'}{$s}) { $ref->{'prev'}{$s} .= "," . $cut[0]} else {$ref->{'prev'}{$s} = $cut[0]}
       }
      }
    }
@@ -97,5 +120,26 @@ sub treate_language {
    }
   close IN;
  }
-split(' ', $site_language) ;
+  $site_language=~  s/,/ /g; $site_language=~  s/ +/ /g;
+  split(' ', $site_language) ;
+}
+
+sub reverse_dic { my @liste=@_;
+  my %ref = ( ) ; my $ref=\%ref;
+  for my $file (@liste) {
+   open IN, "$file";
+   while (<IN>) {
+    next if ($_ =~ /^#/);
+    my $text= $_ ; $text=~ s/\n//;
+    my @text=split(":", $text);
+    my $t=$text[0]; $t=~ s/\n//;
+    my @L= split(",",$text[1]);
+    for my $a (@L) {
+     if ($ref{$a}) {  $ref{$a}.= "," . $t ; }
+     else { $ref{$a} = $t ; }
+    }
+   }
+   close IN;
+  }
+  %ref
 }
