@@ -22,11 +22,14 @@
 
 #include "flydraw.h"
 
+FILE *tikz_file;
+
 char imagefilename[1024];
 char vimgfilename[1024];
+char tikzfilename[1024];
 int sizex, sizey, saved;
 gdImagePtr image=NULL, brushimg=NULL, tileimg=NULL, wimg=NULL;
-int brushed=0, tiled=0, styled=0, width=1, savew=1, wcolor=-1;
+int brushed=0, tiled=0, styled=0, width=1, savew=1, wcolor=-1, width2=4;
 int color_white, color_black, color_bounder, color_frame;
 int linecnt=-100000;
 int tranged=0;
@@ -53,7 +56,7 @@ matrice matrices_pavage[JC_NB_MATRICES+1];
 vecteur vecteurs_pavage[JC_NB_MATRICES+1];
 
 /* les coordonnees du parallelograme de pavage = coordonnees "mathematiques"
- * du parallelogramme contenant l'image a recopier on place ces coorodonnes
+ * du parallelogramme contenant l'image a recopier on place ces coordonnees
  * avec setparallelogram xs,ys,xu,yu,xv,yu
  * xs,ys=coordonnees math du point 0,0,
  * xu,yu coordonnees math de l'horizontale
@@ -65,15 +68,15 @@ double parallogram_fonda[]={0,0,100,0,0,100};
 /* Write the image */
 void output(void)
 {
-    FILE *out;
+  FILE *out;
 
-    if(!image) return;
-    if(imagefilename[0]) {
-      out=fopen(imagefilename,"wb");
-      if(out!=NULL) {gdImageGif(image, out); fclose(out); }
-    }
-    else gdImageGif(image, stdout);
-    saved=1;
+  if(!image) return;
+  if(imagefilename[0]) {
+    out=fopen(imagefilename,"wb");
+    if(out!=NULL) {gdImageGif(image, out); fclose(out); }
+  }
+  else gdImageGif(image, stdout);
+  saved=1;
 }
 
 /* substitute variable names by their environment strings
@@ -82,62 +85,64 @@ void output(void)
  */
 char *substit(char *p)
 {
-    char *pp, *pe;
-    char namebuf[MAX_NAMELEN+1];
-    int i, l;
+  char *pp, *pe;
+  char namebuf[MAX_NAMELEN+1];
+  int i, l;
 
-    pe=strchr(p,'"'); if(pe!=NULL) l=pe-p; else l=MAX_LINELEN;
-    for(pp=find_name_start(p); *pp!=0 && pp-p<l;
-      pp=find_name_start(pe)) {
-      pe=find_name_end(pp);
-      if((pp>p && !isspace(*(pp-1)) && *(pp-1)!=',') ||
-         (*pe!=0 && !isspace(*pe) && *pe!=',')) continue;
-      memmove(namebuf,pp,pe-pp); namebuf[pe-pp]=0;
-      i=search_list(nametab,nametab_no,sizeof(nametab[0]),namebuf);
-      if(i<0) continue;
-      if(nametab[i].type==t_prep && preptab[nametab[i].serial].typ==p_font)
-        break;
-      if(nametab[i].type==t_color)
-        string_modify(p,pp,pe,colortab[nametab[i].serial].def);
-    }
-    return p;
+  pe=strchr(p,'"'); if(pe!=NULL) l=pe-p; else l=MAX_LINELEN;
+  for(pp=find_name_start(p); *pp!=0 && pp-p<l;
+    pp=find_name_start(pe)) {
+    pe=find_name_end(pp);
+    if((pp>p && !isspace(*(pp-1)) && *(pp-1)!=',') ||
+       (*pe!=0 && !isspace(*pe) && *pe!=',')) continue;
+    memmove(namebuf,pp,pe-pp); namebuf[pe-pp]=0;
+    i=search_list(nametab,nametab_no,sizeof(nametab[0]),namebuf);
+    if(i<0) continue;
+    if(nametab[i].type==t_prep && preptab[nametab[i].serial].typ==p_font)
+      break;
+    if(nametab[i].type==t_color)
+      string_modify(p,pp,pe,colortab[nametab[i].serial].def);
+  }
+  return p;
 }
 
-void process(void)
+void fly_process(void)
 {
-    char buf[MAX_LINELEN+1];
-    int c;
-    do {
-      c=ggetline(buf); obj_main(buf);
-    }
-    while(c!=EOF);
+  char buf[MAX_LINELEN+1];
+  int c;
+  do {
+    c=ggetline(buf); obj_main(buf);
+  }
+  while(c!=EOF);
 }
 
 int verify_tables(void) {
-    return evaltab_verify();
+  return evaltab_verify();
 }
 
 int main(int argc, char *argv[])
 {
   int i; for (i = 0; i <= JC_NB_MATRICES; i++)
-	   matrices_pavage [i][0] = matrices_pavage[i][3] = 1;
-    error1=error; error2=error; error3=error;
-    substitute=substit;
-    ev_varcnt=&varcnt; ev_var=vartab;
-    if(argc==2 && strcasecmp(argv[1],"table")==0) {
-      if(verify_tables()) {
-          printf("Table disorder.\n"); return 1;
-      }
-      printf("Table orders OK.\n"); return 0;
+    matrices_pavage [i][0] = matrices_pavage[i][3] = 1;
+  substitute=substit;
+  ev_varcnt=&varcnt; ev_var=vartab;
+  if(argc==2 && strcasecmp(argv[1],"table")==0) {
+    if(verify_tables()) {
+      printf("Table disorder.\n"); return 1;
     }
-    vartab[0].name="animstep"; vartab[0].value=0;
-    varcnt=1;
-    if(argc>1) snprintf(imagefilename,sizeof(imagefilename),"%s",argv[1]);
-    else imagefilename[0]=0;
-    process();
-    if(!saved || imagefilename[0]!=0) output();
-    if(image) gdImageDestroy(image);
-    if(vimg_ready) vimg_close();
-    return 0;
+    printf("Table orders OK.\n"); return 0;
+  }
+  vartab[0].name="animstep"; vartab[0].value=0;
+  varcnt=1;
+  if(argc>1) snprintf(imagefilename,sizeof(imagefilename),"%s",argv[1]);
+  else imagefilename[0]=0;
+  fly_process();
+  if(!saved || imagefilename[0]!=0) output();
+  if(tikz_file){
+    fprintf(tikz_file,"\\end{tikzpicture}\n");
+    fclose(tikz_file);
+  }
+  if(image) gdImageDestroy(image);
+  if(vimg_ready) vimg_close();
+  return 0;
 }
-
