@@ -6,9 +6,9 @@ static char multidraw_primitives[MAX_MULTI_PRIMITIVES][32] = {"point","points","
 "closedpoly","text","rect","rects",
 "poly","polys","parallelogram","parallelograms",
 "images","curvedarrow","curvedarrows","curvedarrow2","curvedarrows2",
-"crosshair","crosshairs"};
+"crosshair","crosshairs","function","functions"};
 /*size of words "point","points",... == 6,7,..*/
-static int multidraw_primitives_length[MAX_MULTI_PRIMITIVES] = {7,6,8,7,6,5,9,8,7,6,10,9,11,5,6,5,6,5,15,14,7,14,13,13,12,10,11};
+static int multidraw_primitives_length[MAX_MULTI_PRIMITIVES] = {6,7,8,7,6,5,9,8,7,6,10,9,11,5,6,5,6,5,15,14,7,14,13,13,12,10,11,9,10};
 
 void add_js_multidraw(char *draw_types,char *table_css,int use_offset,int no_controls,int crosshair_size,int use_zoom){
  int i=0;int p;int found = 0;
@@ -36,7 +36,7 @@ void add_js_multidraw(char *draw_types,char *table_css,int use_offset,int no_con
   /* multidraw_primitives defined in canvasdraw.h */
    equal = strncmp(multidraw_primitives[p],array[i],multidraw_primitives_length[p]);
    if (equal == 0 ){
-/*    fprintf(stdout,"found %s i=%d p=%d<br />",multidraw_primitives[p],i,p);*/
+/*    fprintf(stdout,"found %s i=%d p=%d<br>",multidraw_primitives[p],i,p);*/
     draw_nums[p]= p;user_nums[p] = i;
     found=1; break;
    }
@@ -82,6 +82,7 @@ function scale_multi_radius(r){for(var p = 0 ; p < r.length;p++ ){r[p] = zoom_xy
    case 21 ... 22 :fprintf(js_include_file,"if( curvedarrows_x && curvedarrows_x.length > 0 ){curvedarrows_x = scale_xy(1,curvedarrows_x);curvedarrows_y = scale_xy(2,curvedarrows_y);draw_curvedarrows();};");break;
    case 23 ... 24 :fprintf(js_include_file,"if( curvedarrows2_x && curvedarrows2_x.length > 0 ){curvedarrows2_x = scale_xy(1,curvedarrows2_x);curvedarrows2_y = scale_xy(2,curvedarrows2_y);draw_curvedarrows2();};");break;
    case 25 ... 26 :fprintf(js_include_file,"if( crosshairs_x && crosshairs_x.length > 0 ){crosshairs_x = scale_xy(1,crosshairs_x);crosshairs_y = scale_xy(1,crosshairs_y);draw_crosshairs();};");break;
+   case 27:break;
    default	  : break;
   }
  }
@@ -125,6 +126,7 @@ function scale_multi_radius(r){for(var p = 0 ; p < r.length;p++ ){r[p] = zoom_xy
    case 24:fprintf(js_include_file,"case 24: curvedarrows2(x,y,0,1);break;");break;
    case 25:fprintf(js_include_file,"case 25: crosshairs(x,y,0,0);break;");break;
    case 26:fprintf(js_include_file,"case 26: crosshairs(x,y,0,1);break;");break;
+   case 27:fprintf(js_include_file,"case 27:break;");break;
    default: break;
   }
  }
@@ -170,6 +172,7 @@ function scale_multi_radius(r){for(var p = 0 ; p < r.length;p++ ){r[p] = zoom_xy
    case 24:fprintf(js_include_file,"case 24: curvedarrows2(x,y,1,1);break;");break;
    case 25:fprintf(js_include_file,"case 25: break;");break;
    case 26:fprintf(js_include_file,"case 26: break;");break;
+   case 27:fprintf(js_include_file,"case 27: break;");break;
    default:break;
   }
  }
@@ -207,7 +210,7 @@ int u;
    if( num == 0 ){\
     points_x[0] = xy[0];\
     points_y[0] = xy[1];\
-   }else{\
+   } else {\
     points_x.push(xy[0]);\
     points_y.push(xy[1]);\
    };\
@@ -236,9 +239,7 @@ int u;
    inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td>(<input type='text' size='5' value='' id='input_points_x' />:<input type='text' size='5' value='' id='input_points_y' />)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_points_x,input_points_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -255,16 +256,12 @@ int u;
     if( multidraw_object_cnt == 0 ){\
      if( num  == 0 ){\
        circles_x[0]=xy[0];circles_y[0]=xy[1];multi_radius[0]=4;\
-     }\
-     else\
-     {\
+     } else {\
        circles_x.push(xy[0]);circles_y.push(xy[1]);multi_radius.push(4);\
      };\
     };\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt == 1 ){\
      multi_radius[last] = parseInt(Math.sqrt( (xy[0] - xc)*(xy[0] - xc) + (xy[1] - yc)*(xy[1] - yc) ));\
     };\
@@ -302,9 +299,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td>M:(<input type='text' size='3' value='' id='input_circles_x' /> : <input type='text' size='3' value='' id='input_circles_y'/>) R:<input type='text' size='3' value='' id='input_circles_r'/></td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_circles_x,input_circles_y,input_circles_r);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -320,15 +315,11 @@ int u;
     if(lines_x[p] < lines_x[pp]+marge && lines_x[p] > lines_x[pp]-marge){\
      tmp_x[p] = lines_x[p];tmp_x[pp] = lines_x[pp];\
      tmp_y[p] = 0;tmp_y[pp] = ysize;\
-    }\
-    else\
-    {\
+    } else {\
      if(lines_y[p] < lines_y[pp]+marge && lines_y[p] > lines_y[pp]-marge){\
       tmp_x[p] = 0;tmp_x[pp] = xsize;\
       tmp_y[p] = lines_y[p];tmp_y[pp] = lines_y[pp];\
-     }\
-     else\
-     {\
+     } else {\
       tmp_x[p] = 0;tmp_x[pp] = xsize;\
       tmp_y[p] = lines_y[p] - (lines_x[p])*(lines_y[pp] - lines_y[p])/(lines_x[pp] - lines_x[p]);\
       tmp_y[pp] = lines_y[p] + (xsize - lines_x[p])*(lines_y[pp] - lines_y[p])/(lines_x[pp] - lines_x[p]);\
@@ -342,9 +333,7 @@ int u;
     if( num == 0 && multidraw_object_cnt == 0 ){lines_x = [];lines_y = [];};\
     lines_x.push(xy[0]);lines_y.push(xy[1]);\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt == 1 ){\
      lines_x.push(xy[0]);lines_y.push(xy[1]);\
      draw_lines();\
@@ -382,9 +371,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td>(<input type='text' size='5' value='x1 : y1' id='input_lines_x' style='text-align:center;'/>) --- ( <input type='text' size='5' value='x2 : y2' id='input_lines_y' style='text-align:center;' /> )</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_lines_x,input_lines_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -396,9 +383,7 @@ int u;
     if( num == 0 && multidraw_object_cnt == 0 ){segments_x = [];segments_y = [];};\
     segments_x.push(xy[0]);segments_y.push(xy[1]);\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt == 1 ){\
      segments_x.push(xy[0]);segments_y.push(xy[1]);\
      draw_segments();\
@@ -437,9 +422,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td>(<input type='text' size='5' value='x1 : y1' id='input_segments_x' style='text-align:center;' />) --- ( <input type='text' size='5' value='x2 : y2' id='input_segments_y' style='text-align:center;'/>)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_segments_x,input_segments_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -451,9 +434,7 @@ int u;
     if( num == 0 && multidraw_object_cnt == 0 ){arrows_x = [];arrows_y = [];};\
     arrows_x.push(xy[0]);arrows_y.push(xy[1]);\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt == 1 ){\
      arrows_x.push(xy[0]);arrows_y.push(xy[1]);\
      draw_arrows();\
@@ -507,9 +488,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1){inner_html+=\"<td>(<input type='text' size='5' value='x1 : y1' id='input_arrows_x' style='text-align:center;' /><b>) --- (</b> <input type='text' size='5' value='x2 : y2' id='input_arrows_y' style=';text-align:center;' />)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_arrows_x,input_arrows_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -523,15 +502,11 @@ int u;
     if(num == 0 && multidraw_object_cnt == 0){\
      triangles_x = [];triangles_y = [];\
      triangles_x[0] = xy[0];triangles_y[0] = xy[1];\
-    }\
-    else\
-    {\
+    } else {\
      triangles_x.push(xy[0]);triangles_y.push(xy[1]);\
     };\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt < 3 ){\
      triangles_x.push(xy[0]);triangles_y.push(xy[1]);\
      draw_triangles();\
@@ -575,9 +550,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td><b>(<input type='text' size='5' value='x1 : y1' id='input_triangles_x' />) -- (<input type='text' size='5' value='x2 : y2' id='input_triangles_y' />) -- (<input type='text' size='5' value='x3 : y3' id='input_triangles_r' />)</b></td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_triangles_x,input_triangles_y,input_triangles_r);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -600,9 +573,7 @@ int u;
     if(multidraw_object_cnt == 0){\
      closedpoly_x = [];closedpoly_y = [];\
      closedpoly_x[0] = xy[0];closedpoly_y[0] = xy[1];\
-    }\
-    else\
-    {\
+    } else {\
      closedpoly_x.push(xy[0]);closedpoly_y.push(xy[1]);\
     };\
     multidraw_object_cnt++;\
@@ -612,9 +583,7 @@ int u;
       multidraw_object_cnt = 0;\
      };\
     };\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt > 0 ){\
      closedpoly_x.push(xy[0]);closedpoly_y.push(xy[1]);\
      draw_closedpoly();\
@@ -653,9 +622,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1){inner_html+=\"<td>(<input type='text' size='5' value='x1:x2:x3:...' id='input_closedpoly_x' style='text-align:center;' /><b>) --- (</b> <input type='text' size='5' value='y1:y2:y3:...' id='input_closedpoly_y' style='text-align:center;'/>)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_closedpoly_x,input_closedpoly_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -667,7 +634,7 @@ int u;
    if( num == 0 ){\
     text_x[0] = xy[0];\
     text_y[0] =xy[1];\
-   }else{\
+   } else {\
     text_x.push(xy[0]);\
     text_y.push(xy[1]);\
    };\
@@ -685,7 +652,8 @@ int u;
      text_abc.push(txt);\
     };\
     half = 0.5*( context_text.measureText(text_abc[p]).width );\
-    context_text.fillText(text_abc[p],text_x[p] - half,text_y[p] + height);\
+    if(text_abc[p].indexOf('_') > 0 || text_abc[p].indexOf('^') > 0 ){\
+    draw_subsup(context_text,text_x[p],text_y[p],text_abc[p],4);}else{context_text.fillText(text_abc[p],text_x[p] - half,text_y[p] + height);};\
    };\
   };var canvas_text = create_canvas%d(10%d,xsize,ysize);\
   var context_text = canvas_text.getContext(\"2d\");\
@@ -696,9 +664,7 @@ int u;
 
   if( no_controls != 1 ){  /* for BPR...*/
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt=0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td><td><input type='text' size='6' value='' id='input_text_r' />\";if( multiuserinput[%d] == 1){inner_html+=\"(<input type='text' size='2' value='x' id='input_text_x' style='text-align:center;' />:<input type='text' size='2' value='y' id='input_text_y' style='text-align:center;'/>)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_text_x,input_text_y,input_text_r);' value='OK' /></td>\";}else{inner_html+=\"</td>\";};",u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   fprintf(js_include_file,"inner_html+=\"</tr>\";");
@@ -711,9 +677,7 @@ int u;
     if( num == 0 && multidraw_object_cnt == 0 ){rects_x = [];rects_y = [];};\
     rects_x.push(xy[0]);rects_y.push(xy[1]);\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt == 1 ){\
      rects_x.push(xy[0]);rects_y.push(xy[1]);\
      draw_rects();\
@@ -752,9 +716,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1){inner_html+=\"<td>(<input type='text' size='5' value='x1 : y1' id='input_rects_x' style='text-align:center;' />) --- (<input type='text' size='5' value='x2 : y2' id='input_rects_y' style='text-align:center;' />)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_rects_x,input_rects_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -767,15 +729,11 @@ int u;
     if(num == 0 && multidraw_object_cnt == 0){\
      polys_x = [];polys_y = [];\
      polys_x[0] = xy[0];polys_y[0] = xy[1];\
-    }\
-    else\
-    {\
+    } else {\
      polys_x.push(xy[0]);polys_y.push(xy[1]);\
     };\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt < polynum ){\
      polys_x.push(xy[0]);polys_y.push(xy[1]);\
      draw_polys();\
@@ -820,9 +778,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if(multiuserinput[%d] == 1 ){inner_html+=\"<td>(<input type='text' size='8' value='x1,x2...x_n' id='input_polys_x' /> ---- <input type='text' size='8' value='y1,y2...y_n' id='input_polys_y' />)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_rects_x,input_rects_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -836,9 +792,7 @@ int u;
     if(multidraw_object_cnt == 0){\
      if(num == 0){parallelogram_x = [];parallelogram_y = [];};\
      parallelogram_x.push(xy[0]);parallelogram_y.push(xy[1]);\
-    }\
-    else\
-    {\
+    } else {\
      parallelogram_x.push(xy[0]);parallelogram_y.push(xy[1]);\
      if(multidraw_object_cnt == 2){\
       var xy = multi_snap_check(parallelogram_x[l2] - parallelogram_x[l1] + parallelogram_x[l0],parallelogram_y[l2] - parallelogram_y[l1] + parallelogram_y[l0],parallelogram_snap);\
@@ -847,9 +801,7 @@ int u;
      };\
     };\
     multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if(multidraw_object_cnt == 1){\
      var xxyy = multi_snap_check(parallelogram_x[l1],parallelogram_y[l1],parallelogram_snap);\
      parallelogram_x.push(xxyy[0]);\
@@ -859,9 +811,7 @@ int u;
      draw_parallelogram();\
      parallelogram_x.pop();parallelogram_y.pop();\
      parallelogram_x.pop();parallelogram_y.pop();\
-    }\
-    else\
-    {\
+    } else {\
      if(multidraw_object_cnt == 2){\
       var xxyy = multi_snap_check(parallelogram_x[l2]-parallelogram_x[l1] + parallelogram_x[l0],parallelogram_y[l2]-parallelogram_y[l1] + parallelogram_y[l0],parallelogram_snap);\
       parallelogram_x.push(xy[0]);parallelogram_y.push(xy[1]);\
@@ -914,14 +864,12 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt=0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if(multiuserinput[%d] == 1 ){inner_html+=\"<td>(<input type='text' size='8' value='x1,x2...x_n' id='input_parallelogram_x' /> --- <input type='text' size='8' value='y1,y2...y_n' id='input_parallelogram_y' />)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_parallelogram_x,input_parallelogram_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
-  /* 
-  images : identical ! to userdraw images,bogus_color 
+  /*
+  images : identical ! to userdraw images,bogus_color
   15/1/2021 : corrected long standing flaw regarding "centered" on external stuff
   tested: bitmap,svg,TeX [tested KaTeX]
   */
@@ -943,18 +891,26 @@ int u;
     default: return [x,y];break;\
    };\
   };\
+  const reset_placeable_selection = function(thing){\
+    const placeables = document.querySelectorAll('.canvas_placeable');\
+    placeables.forEach((placeable) => {\
+      placeable.classList.remove('selected');\
+    });\
+    if(thing){thing.classList.add('selected');}\
+  };\
   place_image_on_canvas = function(id){\
-   var thing = document.getElementById(id);\
-   var tag = thing.tagName;\
-   if(tag == 'SVG'){draw_mathml_svg(thing,id);return;};\
-   if(tag == 'DIV' || tag == 'SPAN' || tag == 'P' || tag == 'TD' || tag == 'TH'){draw_mathml_div(thing,id);return;};\
-   var src = thing.src;\
-   var image = new Image();\
-   image.src = src;\
-   image.id = 'placed_'+id;\
-   image.width = thing.width;\
-   image.height = thing.height;\
-   image.onload = function(){ current_id = id; };\
+    var thing = document.getElementById(id);\
+    reset_placeable_selection(thing);\
+    var tag = thing.tagName;\
+    if(tag == 'SVG'){draw_mathml_svg(thing,id);return;};\
+    if(tag == 'DIV' || tag == 'SPAN' || tag == 'P' || tag == 'TD' || tag == 'TH'){draw_mathml_div(thing,id);return;};\
+    var src = thing.src;\
+    var image = new Image();\
+    image.src = src;\
+    image.id = 'placed_'+id;\
+    image.width = thing.width;\
+    image.height = thing.height;\
+    image.onload = function(){ current_id = id; };\
    return;\
   };\
   function draw_mathml_div(thing,id){\
@@ -995,6 +951,7 @@ int u;
     images_x.push(xy[0]);\
     images_y.push(xy[1]);\
     images_id.push(current_id);\
+    reset_placeable_selection();\
     current_id = null;\
    };\
    draw_images();\
@@ -1008,8 +965,10 @@ int u;
       tag = img.tagName;\
       xy = image_adjust(img,images_x[p],images_y[p]);\
       if( tag != 'IMG' ){\
-       img.setAttribute('style','display:block;position:absolute;top:'+xy[1]+'px;left:'+xy[0]+'px;');\
-      }else{\
+        xy[0] = xy[0] / xsize * 100;\
+        xy[1] = xy[1] / ysize * 100;\
+        img.setAttribute('style','display:block;position:absolute;top:'+xy[1]+'%%;left:'+xy[0]+'%%;');\
+      } else {\
        context_images.drawImage(img,xy[0],xy[1],img.width,img.height);\
       };\
      };\
@@ -1023,7 +982,7 @@ int u;
   var images_snap = multisnaptogrid[%d];\
   var images_x = new Array();var images_y = new Array();\
   var images_id = new Array();",use_offset,canvas_root_id,u,i,i);
-  if( no_controls != 1  ){
+  if( no_controls != 1 ){
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt=0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( typeof(imagepalette) === 'object' ){\
    inner_html+=\"<td><table class='%s'><tr>\";\
@@ -1031,10 +990,8 @@ int u;
    if( im %% 4 == 0 ){ inner_html+=\"</tr><tr>\";};\
    inner_html+=\"<td><img onclick='javascript:place_image_on_canvas(this.id);' src='\"+imagepalette[im]+\"' id='imagepalette_\"+im+\"' alt='none'/></td>\";};\
    inner_html+=\"</tr></table></td><td>&nbsp;</td></tr>\";}else{inner_html+=\"<td>&nbsp;</td><td>&nbsp;</td></tr>\";};",u,i,canvas_root_id,u,table_css);
-  }
-  else
-  {
-    fprintf(js_include_file,"inner_html+=\"</table>\";tooltip_div.innerHTML = inner_html;userdraw_primitive = %d;",u);
+  } else {
+    fprintf(js_include_file,"inner_html+=\"</table>\";tooltip_div.innerHTML += inner_html;userdraw_primitive = %d;",u);
   }
   break;
   /* curvedarrow/curvedarrows */
@@ -1045,9 +1002,7 @@ int u;
      xy = multi_snap_check(x,y,curvedarrows_snap);\
      if(num == 0 && multidraw_object_cnt == 0){curvedarrows_x = [];curvedarrows_y = [];curvedarrows_x[0] = xy[0];curvedarrows_y[0] = xy[1];}\
     else{curvedarrows_x.push(xy[0]);curvedarrows_y.push(xy[1]);};multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
     if( multidraw_object_cnt < 3 ){curvedarrows_x.push(xy[0]);curvedarrows_y.push(xy[1]);draw_curvedarrows();curvedarrows_x.pop();curvedarrows_y.pop();};\
     if( multidraw_object_cnt == 3 ){curvedarrows_x.pop();curvedarrows_y.pop();curvedarrows_x.push(xy[0]);curvedarrows_y.push(xy[1]);multidraw_object_cnt = 0;draw_curvedarrows();};\
    };\
@@ -1087,9 +1042,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td><b>(<input type='text' size='5' value='x1 : y1' id='input_curvedarrows_x' />) -- (<input type='text' size='5' value='x2 : y2' id='input_curvedarrows_y' />) -- (<input type='text' size='5' value='x3 : y3' id='input_curvedarrows_r' />)</b></td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_curvedarrows_x,input_curvedarrows_y,input_curvedarrows_r);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -1101,9 +1054,7 @@ int u;
      xy = multi_snap_check(x,y,curvedarrows2_snap);\
      if(num == 0 && multidraw_object_cnt == 0){curvedarrows2_x = [];curvedarrows2_y = [];curvedarrows2_x[0] = xy[0];curvedarrows2_y[0] = xy[1];}\
     else{curvedarrows2_x.push(xy[0]);curvedarrows2_y.push(xy[1]);};multidraw_object_cnt++;\
-   }\
-   else\
-   {\
+   } else {\
    if( multidraw_object_cnt < 3 ){curvedarrows2_x.push(xy[0]);curvedarrows2_y.push(xy[1]);draw_curvedarrows2();curvedarrows2_x.pop();curvedarrows2_y.pop();};\
    if( multidraw_object_cnt == 3 ){curvedarrows2_x.pop();curvedarrows2_y.pop();curvedarrows2_x.push(xy[0]);curvedarrows2_y.push(xy[1]);multidraw_object_cnt = 0;draw_curvedarrows2();};\
    };\
@@ -1147,9 +1098,7 @@ int u;
    fprintf(js_include_file,"inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td><b>(<input type='text' size='5' value='x1 : y1' id='input_curvedarrows2_x' />) -- (<input type='text' size='5' value='x2 : y2' id='input_curvedarrows2_y' />) -- (<input type='text' size='5' value='x3 : y3' id='input_curvedarrows2_r' />)</b></td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_curvedarrows2_x,input_curvedarrows2_y,input_curvedarrows2_r);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
@@ -1160,7 +1109,7 @@ int u;
    if( num == 0 ){\
     crosshairs_x[0] = xy[0];\
     crosshairs_y[0] = xy[1];\
-   }else{\
+   } else {\
     crosshairs_x.push(xy[0]);\
     crosshairs_y.push(xy[1]);\
    };\
@@ -1200,12 +1149,11 @@ int u;
    inner_html+=\"<tr><td><input type='button' onclick='javascript:userdraw_primitive=%d;multidraw_object_cnt = 0;' value='\"+multilabel[%d]+\"' /></td><td><input type='button' onclick='javascript:clear_draw_area%d(%d);' value='delete' /></td>\";\
    if( multiuserinput[%d] == 1 ){inner_html+=\"<td>(<input type='text' size='5' value='' id='input_crosshairs_x' />:<input type='text' size='5' value='' id='input_crosshairs_y' />)</td><td><input type='button' id='canvasdraw_ok_button' onclick='javascript:update_draw_area%d(%d,input_crosshairs_x,input_crosshairs_y,null);' value='OK' /></td></tr>\";}else{inner_html+=\"</tr>\";};",
    u,i,canvas_root_id,u,i,canvas_root_id,u);
-  }
-  else
-  {
+  } else {
    fprintf(js_include_file,"userdraw_primitive = %d;",u);
   }
   break;
+  case 27:break;
 
   /* einde switch */
   default : break;
