@@ -58,6 +58,8 @@ void replace_newline(char *p)
     if(*p=='\n') *p='	';
   }
 }
+/* non existent strings should not compare */
+int my_strcmp(char *a, char *b) {return (a && b)? strcmp(a,b):1; }
 
 /* variable substitution. buffer p must have MAX_LINELEN */
 void subst(char *p)
@@ -83,7 +85,7 @@ void subst(char *p)
     for(pe=pp+1;isalnum(*pe) || *pe=='_'; pe++);
     if(pe-pp>=MAX_NAMELEN) continue;
     memmove(nbuf,pp+1,pe-pp-1);nbuf[pe-pp-1]=0;
-    for(i=varcnt-1;i>=1 && strcmp(nbuf,param[i].name)!=0;i--);
+    for(i=varcnt-1;i>=1 && my_strcmp(nbuf,param[i].name)!=0;i--);
     if(i>=1) {
       if(deftag) param[i].save=1;
       if(*pe=='[') {
