@@ -192,20 +192,21 @@ void examscorecalc(struct classdata *cd, char *uname)
 {
   struct scoredata *thiscore;
   char nbuf[MAX_FNAME+1];
-  char cuttimes[MAX_EXOS][16];
+  char cuttimes[MAX_EXAMS][16];
   char rbuf[MAX_FILELEN+1];
   char *wlist[8];
   char *p1, *p2;
   int i, k, ecnt, num;
-  double ss, sc[MAX_EXOS], sc2[MAX_EXOS], scb[MAX_EXOS], scb2[MAX_EXOS];
-  int ind[MAX_EXOS];
-  unsigned int tr[MAX_EXOS], all[MAX_EXOS], ver[MAX_EXOS], start[MAX_EXOS], dure[MAX_EXOS];
-  char *ip[MAX_EXOS], *ses[MAX_EXOS];
-  unsigned int start1, endtime[MAX_EXOS];
+  double ss, sc[MAX_EXAMS], sc2[MAX_EXAMS], scb[MAX_EXAMS], scb2[MAX_EXAMS];
+  int ind[MAX_EXAMS];
+  unsigned int tr[MAX_EXAMS], all[MAX_EXAMS], ver[MAX_EXAMS], start[MAX_EXAMS], dure[MAX_EXAMS];
+  char *ip[MAX_EXAMS], *ses[MAX_EXAMS];
+  unsigned int start1, endtime[MAX_EXAMS];
   signed int dure1;
 
   ecnt=cd->examcnt;
-  if(ecnt<=0) return; if(ecnt>MAX_EXOS) ecnt=MAX_EXOS;
+  if(ecnt<=0) return;
+  if(ecnt>MAX_EXAMS) ecnt=MAX_EXAMS;
   memset(all,0,sizeof(all)), memset(ver,0,sizeof(ver));
   for(i=0;i<ecnt;i++) {
     ind[i]=i+cd->exam.indstart;
