@@ -140,17 +140,17 @@ void _form_menus(char *p,int kind)
       case FORM_RADIO:
       case FORM_CHECKBOX:
         if (itemcnt > 1) {
-          output("%s<input type=\"%s\" name=\"%s\" id=\"%s_%d\" value=\"%s\"%s/><label for=\"%s_%d\">%s</label>%s",
+          output("%s<input type=\"%s\" name=\"%s\" id=\"%s_%d\" value=\"%s\"%s><label for=\"%s_%d\">%s</label>%s",
            pfrb,name,nbuf,input_id,i+1,p0,pc,input_id,i+1,plist[i],pfre);
         } else {
-          output("%s<input type=\"%s\" name=\"%s\" id=\"%s\" value=\"%s\"%s/><label for=\"%s\">%s</label>%s",
+          output("%s<input type=\"%s\" name=\"%s\" id=\"%s\" value=\"%s\"%s><label for=\"%s\">%s</label>%s",
            pfrb,name,nbuf,input_id,p0,pc,input_id,plist[i],pfre);
         }
         if(i<itemcnt-1 && itemcnt>2 && (hmode==NULL || *hmode==0)) _output_(",");
         _output_("\n");
         break;
       case FORM_BAR:
-        output("<input type=\"%s\" name=\"%s\" id=\"%s_%d\" title=\"%s\" value=\"%s\"%s/><label style=\"display:none\" for=\"%s_%d\">%s</label>",
+        output("<input type=\"%s\" name=\"%s\" id=\"%s_%d\" title=\"%s\" value=\"%s\"%s><label style=\"display:none\" for=\"%s_%d\">%s</label>",
            name,nbuf,input_id,i+1,p0,p0,pc,input_id,i+1,p0);
         break;
     }
@@ -159,7 +159,7 @@ void _form_menus(char *p,int kind)
   setvar("wims_ref_id","");
   setvar("wims_html_mode","");
   if(kind==FORM_SELECT) _output_("</select>");
-  if(kind==FORM_BAR) output("&nbsp;<span style=\"font-weight:bold;\">+</span>%s",pfre);
+  if(kind==FORM_BAR) output("&nbsp;<span style=\"font-weight:bold;\">+</span>");
 }
 
 void exec_formselect(char *p)
